"sealevel" <-
structure(list(dover = c(3.52, 3.6, 3.44, 3.52, 3.7, 3.24, 3.62, 
3.29, 3.75, 3.98, 3.75, 3.34, 3.75, NA, 3.81, NA, 3.54, NA, NA, 
3.41, NA, NA, 3.41, 3.48, 3.41, NA, 3.51, 3.66, 3.44, 3.6, 3.32, 
4.3, 3.72, 3.63, 3.54, 3.63, 3.48, 4.15, 3.51, 3.6, 3.51, 4.57, 
3.66, 3.6, 3.57, 3.63, 3.81, 3.84, 3.51, 4.21, 3.72, 3.59, 3.65, 
3.92, 3.77, 4.08, 3.71, 4.01, 3.53, 3.77, 3.72, 4.06, 3.71, 3.68, 
4.13, 4, NA, 3.7, 3.9, 3.83, 3.66, 4.38, 3.58, 3.55, NA, 3.77, 
3.67, 3.69, 4.06, 3.77, 3.58), harwich = c(NA, NA, NA, NA, NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, 2.41, 2.29, 2.62, 2.44, 2.16, 
2.59, 2.74, 2.19, 2.44, 2.35, 3.05, 2.35, 3.08, 2.62, 2.8, 2.62, 
2.47, 2.83, 3.08, 2.62, 2.35, 2.47, 2.65, 3.26, 2.44, 2.87, 2.68, 
3.99, 2.65, 2.8, 2.44, 2.56, 2.62, 2.62, 2.71, 3.26, 2.77, 2.5, 
2.56, 3.2, 2.8, 2.93, 2.74, 2.96, 2.71, 2.69, 2.59, 2.36, 2.67, 
2.7, 2.9, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
NA, NA, NA)), .Names = c("dover", "harwich"), row.names = c("1912", 
"1913", "1914", "1915", "1916", "1917", "1918", "1919", "1920", 
"1921", "1922", "1923", "1924", "1925", "1926", "1927", "1928", 
"1929", "1930", "1931", "1932", "1933", "1934", "1935", "1936", 
"1937", "1938", "1939", "1940", "1941", "1942", "1943", "1944", 
"1945", "1946", "1947", "1948", "1949", "1950", "1951", "1952", 
"1953", "1954", "1955", "1956", "1957", "1958", "1959", "1960", 
"1961", "1962", "1963", "1964", "1965", "1966", "1967", "1968", 
"1969", "1970", "1971", "1972", "1973", "1974", "1975", "1976", 
"1977", "1978", "1979", "1980", "1981", "1982", "1983", "1984", 
"1985", "1986", "1987", "1988", "1989", "1990", "1991", "1992"
), class = "data.frame")
